diff --git a/aider_gitea/gitea_client.py b/aider_gitea/gitea_client.py
index 76028f8..267c3c7 100644
--- a/aider_gitea/gitea_client.py
+++ b/aider_gitea/gitea_client.py
@@ -158,7 +158,13 @@ class GiteaClient:
             requests.HTTPError: If the API request fails.
         """
         url = f'{self.gitea_url}/repos/{owner}/{repo}/pulls'
-        json_data = {'title': title, 'body': body, 'head': head, 'base': base, 'labels': labels}
+        json_data = {
+            'title': title,
+            'body': body,
+            'head': head,
+            'base': base,
+            'labels': labels,
+        }
 
         response = self.session.post(url, json=json_data)
         response.raise_for_status()
diff --git a/test/test_solve_issue_in_repository.py b/test/test_solve_issue_in_repository.py
new file mode 100644
index 0000000..33c90c8
--- /dev/null
+++ b/test/test_solve_issue_in_repository.py
@@ -0,0 +1,86 @@
+from pathlib import Path
+from unittest.mock import MagicMock, patch
+
+from aider_gitea import solve_issue_in_repository
+
+
+class TestSolveIssueInRepository:
+    def setup_method(self):
+        self.args = MagicMock()
+        self.args.gitea_url = 'https://gitea.example.com'
+        self.args.owner = 'test-owner'
+        self.args.repo = 'test-repo'
+        self.args.base_branch = 'main'
+
+        self.gitea_client = MagicMock()
+        self.tmpdirname = Path('/tmp/test-repo')
+        self.branch_name = 'issue-123-test-branch'
+        self.issue_title = 'Test Issue'
+        self.issue_description = 'This is a test issue'
+        self.issue_number = '123'
+
+    @patch('aider_gitea.secrets.llm_api_key', return_value='fake-api-key')
+    @patch('aider_gitea.run_cmd')
+    @patch('aider_gitea.push_changes')
+    @patch('subprocess.run')
+    def test_solve_issue_with_aider_changes(
+        self, mock_subprocess_run, mock_push_changes, mock_run_cmd, mock_llm_api_key,
+    ):
+        # Setup mocks
+        mock_run_cmd.return_value = True
+        mock_push_changes.return_value = True
+
+        # Mock subprocess.run to return different commit hashes and file changes
+        mock_subprocess_run.side_effect = [
+            MagicMock(stdout='abc123\n', returncode=0),  # First git rev-parse
+            MagicMock(
+                stdout='file1.py\nfile2.py\n', returncode=0,
+            ),  # git diff with changes
+        ]
+
+        # Call the function
+        result = solve_issue_in_repository(
+            self.args,
+            self.tmpdirname,
+            self.branch_name,
+            self.issue_title,
+            self.issue_description,
+            self.issue_number,
+            self.gitea_client,
+        )
+
+        # Verify results
+        assert result is True
+        assert mock_run_cmd.call_count >= 8  # Verify all expected commands were run
+        mock_push_changes.assert_called_once()
+
+    @patch('aider_gitea.secrets.llm_api_key', return_value='fake-api-key')
+    @patch('aider_gitea.run_cmd')
+    @patch('aider_gitea.push_changes')
+    @patch('subprocess.run')
+    def test_solve_issue_without_aider_changes(
+        self, mock_subprocess_run, mock_push_changes, mock_run_cmd, mock_llm_api_key,
+    ):
+        # Setup mocks
+        mock_run_cmd.return_value = True
+
+        # Mock subprocess.run to return same commit hash and no file changes
+        mock_subprocess_run.side_effect = [
+            MagicMock(stdout='abc123\n', returncode=0),  # First git rev-parse
+            MagicMock(stdout='', returncode=0),  # git diff with no changes
+        ]
+
+        # Call the function
+        result = solve_issue_in_repository(
+            self.args,
+            self.tmpdirname,
+            self.branch_name,
+            self.issue_title,
+            self.issue_description,
+            self.issue_number,
+            self.gitea_client,
+        )
+
+        # Verify results
+        assert result is False
+        assert mock_push_changes.call_count == 0  # push_changes should not be called
diff --git a/aider_gitea/__init__.py b/aider_gitea/__init__.py
index 1c300ee..388e033 100644
--- a/aider_gitea/__init__.py
+++ b/aider_gitea/__init__.py
@@ -300,6 +300,21 @@ def solve_issue_in_repository(
     run_cmd(['git', 'checkout', args.base_branch], tmpdirname)
     run_cmd(['git', 'checkout', '-b', branch_name], tmpdirname)
 
+    # Run initial ruff pass before aider
+    run_cmd(['bash', '-c', RUFF_FORMAT_AND_AUTO_FIX], tmpdirname, check=False)
+    run_cmd(['git', 'add', '.'], tmpdirname)
+    run_cmd(['git', 'commit', '-m', 'Initial ruff pass'], tmpdirname, check=False)
+
+    # Save the commit hash after ruff but before aider
+    result = subprocess.run(
+        ['git', 'rev-parse', 'HEAD'],
+        check=True,
+        cwd=tmpdirname,
+        capture_output=True,
+        text=True,
+    )
+    pre_aider_commit = result.stdout.strip()
+
     # Run aider
     issue_content = f'# {issue_title}\n{issue_description}'
     succeeded = run_cmd(
@@ -311,10 +326,27 @@ def solve_issue_in_repository(
         logger.error('Aider invocation failed for issue #%s', issue_number)
         return False
 
     # Auto-fix standard code quality stuff
     run_cmd(['bash', '-c', RUFF_FORMAT_AND_AUTO_FIX], tmpdirname, check=False)
     run_cmd(['git', 'add', '.'], tmpdirname)
-    run_cmd(['git', 'commit', '-m', 'Ruff'], tmpdirname, check=False)
+    run_cmd(['git', 'commit', '-m', 'Ruff after aider'], tmpdirname, check=False)
+
+    # Check if aider made any changes beyond the initial ruff pass
+    result = subprocess.run(
+        ['git', 'diff', pre_aider_commit, 'HEAD', '--name-only'],
+        check=True,
+        cwd=tmpdirname,
+        capture_output=True,
+        text=True,
+    )
+    files_changed = result.stdout.strip()
+
+    if not files_changed:
+        logger.info(
+            'Aider did not make any changes beyond the initial ruff pass for issue #%s',
+            issue_number,
+        )
+        return False
 
     # Push changes
     return push_changes(
@@ -311,10 +326,27 @@ def solve_issue_in_repository(
         return False
 
-    # Auto-fix standard code quality stuff
+    # Auto-fix standard code quality stuff after aider
     run_cmd(['bash', '-c', RUFF_FORMAT_AND_AUTO_FIX], tmpdirname, check=False)
     run_cmd(['git', 'add', '.'], tmpdirname)